[PATCH] x86-64/memset: Mark the debugger symbol as hidden

H.J. Lu hongjiu.lu@intel.com
Sat May 5 15:46:00 GMT 2018


When MEMSET_SYMBOL (__memset, erms) is provided for debugger, mark it
as hidden so that it will be local to the library.

Any comments?

H.J.
---
	* sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S
	(MEMSET_SYMBOL (__memset, erms)): Mark the debugger symbol as
	hidden.
---
 sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S b/sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S
index d0fe79c9f1..a0560cd5c8 100644
--- a/sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S
+++ b/sysdeps/x86_64/multiarch/memset-vec-unaligned-erms.S
@@ -131,7 +131,8 @@ END (__memset_chk_erms)
 /* Only used to measure performance of REP STOSB.  */
 ENTRY (__memset_erms)
 # else
-/* Provide a symbol to debugger.  */
+/* Provide a hidden symbol to debugger.  */
+	.hidden	MEMSET_SYMBOL (__memset, erms)
 ENTRY (MEMSET_SYMBOL (__memset, erms))
 # endif
 L(stosb):
-- 
2.17.0



More information about the Libc-alpha mailing list